/*
 * vi: formatoptions+=tc textwidth=80 tabstop=8 shiftwidth=8 noexpandtab:
 *
 * $Id: usblan.h,v 1.6 2013/04/10 04:17:06 jaymzh Exp $
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * (C) Copyright Kevin Timmerman 2007
 */

#ifndef USBLAN_H
#define USBLAN_H

#include "lc_internal.h"

int InitializeUsbLan(void);
int ShutdownUsbLan(void);
int FindUsbLanRemote(void);
int UsbLan_Write(unsigned int len, uint8_t *data);
int UsbLan_Read(unsigned int &len, uint8_t *data);
int GetXMLUserRFSetting(char **data);

#endif
